@@ -147,10 +147,6 @@ void
 on_button9_clicked                     (GtkButton       *button,
                                         gpointer         user_data);
 
-void
-on_button10_clicked                    (GtkButton       *button,
-                                        gpointer         user_data);
-
 void
 on_button11_clicked                    (GtkButton       *button,
                                         gpointer         user_data);
@@ -198,14 +194,6 @@ void
 on_button13_clicked                    (GtkButton       *button,
                                         gpointer         user_data);
 
-void
-on_button16_clicked                    (GtkButton       *button,
-                                        gpointer         user_data);
-
-void
-on_button17_clicked                    (GtkButton       *button,
-                                        gpointer         user_data);
-
 void
 on_button18_clicked                    (GtkButton       *button,
                                         gpointer         user_data);
@@ -349,13 +337,6 @@ on_item14_activate                     (GtkWidget       *widget,
                                         GdkEventButton  *event,
                                         gpointer         user_data);
 
-void
-on_radiobutton1_toggled                (GtkToggleButton *togglebutton,
-                                        gpointer         user_data);
-
-void
-on_radiobutton13_toggled               (GtkToggleButton *togglebutton,
-                                        gpointer         user_data);
 
 void
 on_entry16_changed                     (GtkEditable     *editable,
@@ -393,29 +374,6 @@ void
 on_radiobutton21_toggled               (GtkToggleButton *togglebutton,
                                         gpointer         user_data);
 
-void
-on_checkbutton3_toggled                (GtkToggleButton *togglebutton,
-                                        gpointer         user_data);
-
-void
-on_checkbutton4_toggled                (GtkToggleButton *togglebutton,
-                                        gpointer         user_data);
-
-void
-on_checkbutton5_toggled                (GtkToggleButton *togglebutton,
-                                        gpointer         user_data);
-
-void
-on_checkbutton6_toggled                (GtkToggleButton *togglebutton,
-                                        gpointer         user_data);
-
-void
-on_checkbutton7_toggled                (GtkToggleButton *togglebutton,
-                                        gpointer         user_data);
-
-void
-on_checkbutton8_toggled                (GtkToggleButton *togglebutton,
-                                        gpointer         user_data);
 
 gboolean
 on_button11_expose_event               (GtkWidget       *widget,
@@ -640,9 +598,9 @@ on_drawingarea3_expose_event           (GtkWidget       *widget,
                                         GdkEventExpose  *event,
                                         gpointer         user_data);
 
-void
-on_itemgeocode1_activate               (GtkMenuItem     *menuitem,
-                                        gpointer         user_data);
+//void
+//on_itemgeocode1_activate               (GtkMenuItem     *menuitem,
+//                                        gpointer         user_data);
 
 void
 on_itemimport1_activate                (GtkMenuItem     *menuitem,
@@ -739,3 +697,155 @@ on_button50_clicked                    (GtkButton       *button,
 void
 on_closebutton2_clicked                (GtkButton       *button,
                                         gpointer         user_data);
+
+void
+on_radiobutton27_toggled               (GtkToggleButton *togglebutton,
+                                        gpointer         user_data);
+
+void
+on_radiobutton28_toggled               (GtkToggleButton *togglebutton,
+                                        gpointer         user_data);
+
+void
+on_radiobutton29_toggled               (GtkToggleButton *togglebutton,
+                                        gpointer         user_data);
+
+void
+on_button51_clicked                    (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_button52_clicked                    (GtkButton       *button,
+                                        gpointer         user_data);
+
+gboolean
+on_itemgeocode1_activate               (GtkWidget       *widget,
+                                        GdkEventButton  *event,
+                                        gpointer         user_data);
+
+gboolean
+on_item17_button_release_event         (GtkWidget       *widget,
+                                        GdkEventButton  *event,
+                                        gpointer         user_data);
+
+gboolean
+on_item18_button_release_event         (GtkWidget       *widget,
+                                        GdkEventButton  *event,
+                                        gpointer         user_data);
+
+
+void
+on_button57_clicked                    (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_button58_clicked                    (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_entry30_activate                    (GtkEntry        *entry,
+                                        gpointer         user_data);
+
+void
+on_cancelbutton9_clicked               (GtkButton       *button,
+                                        gpointer         user_data);
+
+gboolean
+on_eventbox5_button_release_event      (GtkWidget       *widget,
+                                        GdkEventButton  *event,
+                                        gpointer         user_data);
+
+gboolean
+on_item22_button_release_event         (GtkWidget       *widget,
+                                        GdkEventButton  *event,
+                                        gpointer         user_data);
+
+gboolean
+on_item23_button_release_event         (GtkWidget       *widget,
+                                        GdkEventButton  *event,
+                                        gpointer         user_data);
+
+void
+on_button59_clicked                    (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_button60_clicked                    (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_button61_clicked                    (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_cancelbutton10_clicked              (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_okbutton11_clicked                  (GtkButton       *button,
+                                        gpointer         user_data);
+
+gboolean
+on_dialog10_delete_event               (GtkWidget       *widget,
+                                        GdkEvent        *event,
+                                        gpointer         user_data);
+
+void
+on_entry32_activate                    (GtkEntry        *entry,
+                                        gpointer         user_data);
+
+void
+on_combobox8_changed                   (GtkComboBox     *combobox,
+                                        gpointer         user_data);
+
+void
+on_button76_clicked                    (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_button69_clicked                    (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_button71_clicked                    (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_button70_clicked                    (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_button76_clicked                    (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_checkbutton15_toggled               (GtkToggleButton *togglebutton,
+                                        gpointer         user_data);
+
+void
+on_button78_clicked                    (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_checkbutton16_toggled               (GtkToggleButton *togglebutton,
+                                        gpointer         user_data);
+
+void
+on_checkbutton17_toggled               (GtkToggleButton *togglebutton,
+                                        gpointer         user_data);
+
+void
+on_button79_clicked                    (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_entry29_changed                     (GtkEditable     *editable,
+                                        gpointer         user_data);
+
+void
+on_checkbutton18_toggled               (GtkToggleButton *togglebutton,
+                                        gpointer         user_data);
+
+void
+on_entry33_changed                     (GtkEditable     *editable,
+                                        gpointer         user_data);
