@@ -6,22 +6,35 @@
 #include <gtk/gtk.h>
 #include <gconf/gconf-client.h>
 
+#define MSG_SEND_URL "http://tangogps.org/friends/msg_send.php"
+
 #define GCONF "/apps/tangogps"
 #define TILESIZE 256
 #define PNAME "tangogps"
+#define MAP_PAGE 0
+#define FRIENDS_PAGE 1
+
+#define TRACKPOINT_LIST_MAX_LENGTH 10000	/* max points to keep in mem */
+#define TRIP_DELTA_MIN 0.005			/* min distance between points to log: 5m */
+#define SEGMENT_DISTANCE 100			/* start a new segment when distance exceeds: 100m */
 
 typedef struct {
+	int   time;
+	char  *time_iso8106;
 	float lat;
 	float lon;
-//	int pixel_x;
-//	int pixel_y;
+	float lat_deg;
+	float lon_deg;
+	float alt;
+	float speed;
+	float head;
+	float hdop;
+	int   heart;
 } trackpoint_t;
 
 typedef struct {
 	double lat;
 	double lon;
-//	int pixel_x;
-//	int pixel_y;
 } waypoint_t;
 
 typedef struct {
@@ -31,18 +44,6 @@ typedef struct {
 	int inverted_zoom;
 } repo_t;
 
-typedef struct {
-	int type;
-	char *nick;
-	float lat;
-	float lon;
-	int head;
-	int speed;
-	char *lastseen;
-	char *away_msg;
-	int screen_x;
-	int screen_y;
-} friend_t;
 
 typedef struct {
 	char *filename;
@@ -71,14 +72,14 @@ typedef struct {
 } poi_t;
 
 typedef struct {
-    double time;        /* Time of update, seconds since Unix epoch */
-    int    mode;        /* Mode of fix */
-    double latitude;    /* Latitude in degrees (valid if mode >= 2) */
-    double longitude;   /* Longitude in degrees (valid if mode >= 2) */
-    double altitude;    /* Altitude in meters (valid if mode == 3) */
-    double track;       /* Course made good (relative to true north) */
-    double speed;       /* Speed over ground, meters/sec */
-    double bearing;	/* in radian */
+	double time;		/* Time of update, seconds since Unix epoch */
+	int    mode;		/* Mode of fix */
+	double latitude;	/* Latitude in degrees (valid if mode >= 2) */
+	double longitude;	/* Longitude in degrees (valid if mode >= 2) */
+	double altitude;	/* Altitude in meters (valid if mode == 3) */
+	double heading;
+	double speed;		/* Speed over ground, meters/sec */
+	double bearing;		/* in radian, calculated by tangogps */
 } gps_fix_t;
 
 typedef struct {
@@ -90,6 +91,12 @@ typedef struct {
 	gboolean seen_vaild; /* ever had a vaild fix? */
 } gps_data_t;
 
+typedef struct {
+	int freq;
+	int min;
+	int max;
+} hrm_data_t;
+
 extern GdkPixmap 	*pixmap;
 extern GtkWidget	*window1, *window2;
 extern GtkWidget	*map_drawable;
@@ -97,12 +104,15 @@ extern GtkWidget	*dialog1;
 extern GtkWidget	*dialog8;
 extern GtkWidget	*window3;
 extern GtkWidget	*menu1;
-//extern char repo_dir[]; //FIXME: delete me
+extern GList		*global_infopane_widgets;
+extern GList		*global_infopane_current;
+
 extern char *global_track_dir;
 
 extern int global_x;
 extern int global_y;
 extern int global_zoom;
+extern int global_zoom_max;
 
 extern int mouse_dx; // for mouse move pixmap
 extern int mouse_dy;
@@ -116,13 +126,13 @@ extern int global_drawingarea_height;
 
 
 extern gps_data_t *gpsdata;
+extern hrm_data_t *hrmdata;
 
-//extern trackpoint_t global_track_arr[10];
-
-extern GSList		*trackpoint_list;
+extern GQueue		*trackpoint_list;
 extern GSList		*friends_list;
 extern GSList		*photo_list;
 extern GSList		*poi_list;
+extern GSList		*msg_list;
 extern float		trip_distance;
 extern double		trip_maxspeed;
 extern double		trip_time;
@@ -130,42 +140,62 @@ extern double		trip_starttime;
 extern gboolean		trip_counter_on;
 extern trackpoint_t	global_myposition;
 extern gboolean		trip_logger_on;
+extern gboolean		trip_livelog_on;
+extern gboolean		hrm_on;
 
 extern gchar		*global_curr_reponame;
 extern int		global_repo_cnt;
+extern int		global_repo_nr;
 extern GSList	 	*global_repo_list, *global_curr_repo;
 extern GConfClient	*global_gconfclient;
 
+extern gboolean		global_infopane_visible;
+extern gboolean		global_livelog_on;
+extern gboolean		global_landscape;
 extern gboolean		global_auto_download;
 extern gboolean		global_mapmode;
 extern gboolean		global_autocenter;
 extern gboolean		global_reconnect_gpsd;
+extern gboolean		global_reconnect_hrm;
 extern int		global_tiles_in_dl_queue;
 
 extern gboolean		global_show_pois;
 extern gboolean		global_show_friends;
 extern gboolean		global_show_photos;
+extern gboolean		global_new_msg;
 extern int		global_poi_cat;
 
 extern gboolean		global_wp_on;
 extern waypoint_t	global_wp;
 
-extern gboolean		global_ffupdate_auto;
+extern char		*global_friend_nick;
+extern char		*global_friend_pass;
+
 extern int		global_ffupdate_interval;
 extern double		global_ffupdate_interval_minutes;
 extern gboolean		global_fftimer_running;
-extern gboolean		global_ffcm_public;
-extern gboolean		global_ffcm_registered;
-extern gboolean		global_ffcm_friends;
-extern gboolean		global_ffcu_public;
-extern gboolean		global_ffcu_registered;
-extern gboolean		global_ffcu_friends;
+extern int		global_ff_mode;
 
 extern gchar		*global_server;
 extern gchar		*global_port;
 
+extern gchar		*global_hrm_bt_addr;
+
 extern gchar		*global_home_dir;
 extern gchar		*tangogps_dir;
 
 extern int		mouse_x;
 extern int		mouse_y;
+
+
+enum {
+	PRIVATE_MODE = 1,
+	FRIEND_MODE = 2,
+	FUN_MODE = 3
+};
+
+enum {
+	METRICAL = 0,
+	IMPERIAL = 1,
+	NAUTICAL = 2
+};
